#ifndef NT2_INCLUDE_FUNCTIONS_INV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INV_HPP_INCLUDED

#include <nt2/linalg/include/functions/inv.hpp>

#endif
